@@ -1,6 +1,6 @@
 #__init__.py
 # Version of pepfeature package
-__version__ = "1.0.2"
+__version__ = "1.0.3"
 
 """Import all modules that exist in the current directory."""
 # Ref https://stackoverflow.com/a/60861023/
@@ -9,7 +9,7 @@ from pathlib import Path
 
 for f in Path(__file__).parent.glob("*.py"):
     module_name = f.stem
-    if (not module_name.startswith("_")) and (module_name not in globals()):
+    if (module_name not in globals()):
         import_module(f".{module_name}", __package__)
     del f, module_name
 del import_module, Path
